An output produced by an agent in response to a task.
Artifacts contain typed parts representing the result of agent work.
Summary
Functions
Creates a new artifact from parts.
Types
Functions
@spec new([A2A.Part.t()], keyword()) :: t()
Creates a new artifact from parts.