An output produced by an agent in response to a task.
Artifacts contain typed parts representing the result of agent work.
Summary
Functions
Creates a new artifact from parts.
Types
@type t() :: %A2A.Artifact{ artifact_id: String.t(), description: String.t() | nil, metadata: map(), name: String.t() | nil, parts: [A2A.Part.t()] }
Functions
@spec new( [A2A.Part.t()], keyword() ) :: t()
Creates a new artifact from parts.