Represents file content with either inline bytes or a URI reference.
At least one of bytes or uri must be provided.
Summary
Functions
Creates a new FileContent with inline bytes.
Creates a new FileContent with a URI reference.
Represents file content with either inline bytes or a URI reference.
At least one of bytes or uri must be provided.
Creates a new FileContent with inline bytes.
Creates a new FileContent with a URI reference.