The current status of a task, including state, optional message, and timestamp.
Summary
Functions
Creates a new status with the given state and current timestamp.
Types
@type state() ::
:submitted
| :working
| :input_required
| :completed
| :canceled
| :failed
| :rejected
| :auth_required
| :unknown
@type t() :: %A2A.Task.Status{ message: A2A.Message.t() | nil, state: state(), timestamp: DateTime.t() }
Functions
@spec new(state(), A2A.Message.t() | nil) :: t()
Creates a new status with the given state and current timestamp.